@@ -18,6 +18,7 @@ class MainBaseHandler(tornado.web.RequestHandler):
         self.body = {}
         self._page_data = dict()
         self._redirect = None
+        self._error = False
 
     ##################################################
     # The follow method are what should be implemented
@@ -61,21 +62,23 @@ class MainBaseHandler(tornado.web.RequestHandler):
         '''
         pass
 
-    # def _handle_request_exception(self, e):
-    #     if isinstance(e, tornado.web.HTTPError):
-    #         response = e.log_message
-    #         code = e.status_code
-    #     elif isinstance(e, ApiError):
-    #         response = e.message
-    #         code = e.code
-    #     else:
-    #         code = 500
-    #         response = str(e)
-    # 
-    #     # TODO: add some logging here
-    #     # TODO: if in debug mode, raise all exceptions
-    # 
-    #     return self._respond((code, response))
+    def _handle_request_exception(self, e):
+        self._error = True
+        raise e
+        # if isinstance(e, tornado.web.HTTPError):
+        #     response = e.log_message
+        #     code = e.status_code
+        # elif isinstance(e, ApiError):
+        #     response = e.message
+        #     code = e.code
+        # else:
+        #     code = 500
+        #     response = str(e)
+        #     
+        # # TODO: add some logging here
+        # # TODO: if in debug mode, raise all exceptions
+        #     
+        # return self._respond((code, response))
 
 
     ##################################################
@@ -114,6 +117,9 @@ class MainBaseHandler(tornado.web.RequestHandler):
         self.http_error(code, message)
 
     def on_finish(self):
+        if self._error:
+            return True
+
         if self.method == 'get':
             self.on_finish_get()
         elif self.method == 'post':
